@@ -94,7 +94,6 @@ bool notcurses_canchangecolor(const struct notcurses* nc);
 bool notcurses_canopen_images(const struct notcurses* nc);
 bool notcurses_canopen_videos(const struct notcurses* nc);
 bool notcurses_canutf8(const struct notcurses* nc);
-bool notcurses_cansixel(const struct notcurses* nc);
 int notcurses_mouse_enable(struct notcurses* n);
 int notcurses_mouse_disable(struct notcurses* n);
 int ncplane_destroy(struct ncplane* ncp);
@@ -126,7 +125,7 @@ typedef enum {
   NCBLIT_4x1,
   NCBLIT_BRAILLE,
   NCBLIT_8x1,
-  NCBLIT_SIXEL,
+  NCBLIT_PIXEL,
 } ncblitter_e;
 const char* notcurses_str_blitter(ncblitter_e blitter);
 int notcurses_lex_blitter(const char* op, ncblitter_e* blitter);
@@ -411,7 +410,7 @@ void ncreader_destroy(struct ncreader* n, char** contents);
 int ncplane_puttext(struct ncplane* n, int y, ncalign_e align, const char* text, size_t* bytes);
 int ncplane_putnstr_yx(struct ncplane* n, int y, int x, size_t s, const char* gclusters);
 int ncplane_putnstr_aligned(struct ncplane* n, int y, ncalign_e align, size_t s, const char* gclustarr);
-int ncplane_qrcode(struct ncplane* n, ncblitter_e blitter, int* ymax, int* xmax, const void* data, size_t len);
+int ncplane_qrcode(struct ncplane* n, int* ymax, int* xmax, const void* data, size_t len);
 struct ncdirect* ncdirect_init(const char* termtype, FILE* fp, uint64_t flags);
 int ncdirect_set_bg_rgb8(struct ncdirect* n, unsigned r, unsigned g, unsigned b);
 int ncdirect_set_fg_rgb8(struct ncdirect* n, unsigned r, unsigned g, unsigned b);
